@@ -37,28 +37,28 @@ void FreeBusyGanttProxyModelTest::testModelValidity()
 
     Q_UNUSED(modelTest)
 
-    QVERIFY(ganttModel->rowCount() == 0);
+    QCOMPARE(ganttModel->rowCount(), 0);
 
     const QDateTime dt1(QDate(2010, 8, 24), QTime(7, 0, 0), QTimeZone::utc());
     const QDateTime dt2(QDate(2010, 8, 24), QTime(16, 0, 0), QTimeZone::utc());
-    KCalendarCore::Attendee a1(u"fred"_s, QStringLiteral("fred@example.com"));
-    KCalendarCore::FreeBusy::Ptr fb1(new KCalendarCore::FreeBusy());
+    KCalendarCore::Attendee const a1(u"fred"_s, QStringLiteral("fred@example.com"));
+    KCalendarCore::FreeBusy::Ptr const fb1(new KCalendarCore::FreeBusy());
 
     fb1->addPeriod(dt1, KCalendarCore::Duration(60 * 60));
     fb1->addPeriod(dt2, KCalendarCore::Duration(60 * 60));
 
-    CalendarSupport::FreeBusyItem::Ptr item1(new CalendarSupport::FreeBusyItem(a1, nullptr));
+    CalendarSupport::FreeBusyItem::Ptr const item1(new CalendarSupport::FreeBusyItem(a1, nullptr));
     item1->setFreeBusy(fb1);
 
     const QDateTime dt3(QDate(2010, 8, 25), QTime(7, 0, 0), QTimeZone::utc());
     const QDateTime dt4(QDate(2010, 8, 25), QTime(16, 0, 0), QTimeZone::utc());
-    KCalendarCore::Attendee a2(u"joe"_s, QStringLiteral("joe@example.com"));
-    KCalendarCore::FreeBusy::Ptr fb2(new KCalendarCore::FreeBusy());
+    KCalendarCore::Attendee const a2(u"joe"_s, QStringLiteral("joe@example.com"));
+    KCalendarCore::FreeBusy::Ptr const fb2(new KCalendarCore::FreeBusy());
 
     fb2->addPeriod(dt3, KCalendarCore::Duration(60 * 60));
     fb2->addPeriod(dt4, KCalendarCore::Duration(60 * 60));
 
-    CalendarSupport::FreeBusyItem::Ptr item2(new CalendarSupport::FreeBusyItem(a2, nullptr));
+    CalendarSupport::FreeBusyItem::Ptr const item2(new CalendarSupport::FreeBusyItem(a2, nullptr));
     item2->setFreeBusy(fb2);
 
     fbModel->addItem(item1);
@@ -66,23 +66,23 @@ void FreeBusyGanttProxyModelTest::testModelValidity()
 
     QCOMPARE(ganttModel->rowCount(), 2);
 
-    QModelIndex parent0 = ganttModel->index(0, 0);
-    QModelIndex parent1 = ganttModel->index(1, 0);
-    QModelIndex parent2 = ganttModel->index(2, 0);
+    QModelIndex const parent0 = ganttModel->index(0, 0);
+    QModelIndex const parent1 = ganttModel->index(1, 0);
+    QModelIndex const parent2 = ganttModel->index(2, 0);
     QVERIFY(parent0.isValid());
     QVERIFY(parent1.isValid());
-    QVERIFY(parent2.isValid() == false);
+    QCOMPARE(parent2.isValid(), false);
 
-    QModelIndex source_parent0 = fbModel->index(0, 0);
+    QModelIndex const source_parent0 = fbModel->index(0, 0);
     QCOMPARE(parent0.data(), source_parent0.data());
     QCOMPARE(parent0.data(KGantt::ItemTypeRole).toInt(), (int)KGantt::TypeMulti);
 
-    QModelIndex source_parent1 = fbModel->index(1, 0);
+    QModelIndex const source_parent1 = fbModel->index(1, 0);
     QCOMPARE(parent1.data(), source_parent1.data());
     QCOMPARE(parent1.data(KGantt::ItemTypeRole).toInt(), (int)KGantt::TypeMulti);
 
-    QModelIndex child0_0 = ganttModel->index(0, 0, parent0);
-    QModelIndex child0_1 = ganttModel->index(1, 0, parent0);
+    QModelIndex const child0_0 = ganttModel->index(0, 0, parent0);
+    QModelIndex const child0_1 = ganttModel->index(1, 0, parent0);
     QVERIFY(child0_0.isValid());
     QVERIFY(child0_1.isValid());
 
@@ -91,8 +91,8 @@ void FreeBusyGanttProxyModelTest::testModelValidity()
     QCOMPARE(child0_1.data(KGantt::ItemTypeRole).toInt(), (int)KGantt::TypeTask);
     QCOMPARE(child0_1.data(KGantt::StartTimeRole).toDateTime(), dt2);
 
-    QModelIndex child1_0 = ganttModel->index(0, 0, parent1);
-    QModelIndex child1_1 = ganttModel->index(1, 0, parent1);
+    QModelIndex const child1_0 = ganttModel->index(0, 0, parent1);
+    QModelIndex const child1_1 = ganttModel->index(1, 0, parent1);
     QVERIFY(child1_0.isValid());
     QVERIFY(child1_1.isValid());
 
