@@ -53,12 +53,12 @@ KCalendarCore::Attachment AttachmentIconItem::attachment() const
     return mAttachment;
 }
 
-const QString AttachmentIconItem::uri() const
+QString AttachmentIconItem::uri() const
 {
     return mAttachment.uri();
 }
 
-const QString AttachmentIconItem::savedUri() const
+QString AttachmentIconItem::savedUri() const
 {
     return mSaveUri;
 }
@@ -76,7 +76,7 @@ void AttachmentIconItem::setData(const QByteArray &data)
     readAttachment();
 }
 
-const QString AttachmentIconItem::mimeType() const
+QString AttachmentIconItem::mimeType() const
 {
     return mAttachment.mimeType();
 }
@@ -87,7 +87,7 @@ void AttachmentIconItem::setMimeType(const QString &mime)
     readAttachment();
 }
 
-const QString AttachmentIconItem::label() const
+QString AttachmentIconItem::label() const
 {
     return mAttachment.label();
 }
@@ -108,7 +108,7 @@ bool AttachmentIconItem::isBinary() const
 
 QIcon AttachmentIconItem::icon() const
 {
-    QMimeDatabase db;
+    QMimeDatabase const db;
     return icon(db.mimeTypeForName(mAttachment.mimeType()), mAttachment.uri(), mAttachment.isBinary());
 }
 
@@ -128,7 +128,7 @@ void AttachmentIconItem::readAttachment()
     setText(mAttachment.label());
     setFlags(flags() | Qt::ItemIsEditable);
 
-    QMimeDatabase db;
+    QMimeDatabase const db;
     if (mAttachment.mimeType().isEmpty() || !(db.mimeTypeForName(mAttachment.mimeType()).isValid())) {
         QMimeType attachmentMimeType;
         if (mAttachment.isUri()) {
@@ -167,7 +167,7 @@ QUrl AttachmentIconItem::tempFileForAttachment()
     }
     QTemporaryFile *file = nullptr;
 
-    QMimeDatabase db;
+    QMimeDatabase const db;
     QStringList patterns = db.mimeTypeForName(mAttachment.mimeType()).globPatterns();
 
     if (!patterns.empty()) {
