@@ -4,12 +4,11 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_GROUPWAREUIDELEGATE_H
-#define INCIDENCEEDITOR_GROUPWAREUIDELEGATE_H
+#pragma once
 
 #include "incidenceeditor_export.h"
 
-#include <Akonadi/Calendar/ITIPHandler>
+#include <Akonadi/ITIPHandler>
 
 // Class to edit counter proposals through incidence editors
 namespace IncidenceEditorNG
@@ -22,5 +21,3 @@ public:
     void createCalendar() override;
 };
 }
-
-#endif
