@@ -19,7 +19,7 @@ using namespace Qt::Literals::StringLiterals;
 
 using namespace IncidenceEditorNG;
 
-static bool identical(QDateTime dt1, QDateTime dt2)
+static bool identical(const QDateTime &dt1, const QDateTime &dt2)
 {
     return dt1 == dt2 && dt1.timeSpec() == dt2.timeSpec() && dt1.timeZone() == dt2.timeZone();
 }
@@ -33,12 +33,12 @@ static bool incidenceHasDefaultTimes(const KCalendarCore::Incidence::Ptr &incide
         return false;
     }
 
-    QTime defaultDuration = CalendarSupport::KCalPrefs::instance()->defaultDuration().time();
+    QTime const defaultDuration = CalendarSupport::KCalPrefs::instance()->defaultDuration().time();
     if (!defaultDuration.isValid()) {
         return false;
     }
 
-    QTime defaultStart = CalendarSupport::KCalPrefs::instance()->mStartTime.time();
+    QTime const defaultStart = CalendarSupport::KCalPrefs::instance()->mStartTime.time();
     if (!defaultStart.isValid()) {
         return false;
     }
@@ -123,6 +123,13 @@ bool IncidenceDateTime::eventFilter(QObject *obj, QEvent *event)
     }
 }
 
+void IncidenceDateTime::showMessage(const QString &message, KMessageWidget::MessageType type)
+{
+    mUi->mMessageWidget->setText(message);
+    mUi->mMessageWidget->setMessageType(type);
+    mUi->mMessageWidget->show();
+}
+
 void IncidenceDateTime::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
     if (mLoadedIncidence && *mLoadedIncidence == *incidence) {
@@ -137,11 +144,11 @@ void IncidenceDateTime::load(const KCalendarCore::Incidence::Ptr &incidence)
     mLoadingIncidence = true;
 
     // We can only handle events or todos.
-    if (KCalendarCore::Todo::Ptr todo = IncidenceDateTime::incidence<KCalendarCore::Todo>()) {
+    if (KCalendarCore::Todo::Ptr const todo = IncidenceDateTime::incidence<KCalendarCore::Todo>()) {
         load(todo, isTemplate, templateOverridesTimes);
-    } else if (KCalendarCore::Event::Ptr event = IncidenceDateTime::incidence<KCalendarCore::Event>()) {
+    } else if (KCalendarCore::Event::Ptr const event = IncidenceDateTime::incidence<KCalendarCore::Event>()) {
         load(event, isTemplate, templateOverridesTimes);
-    } else if (KCalendarCore::Journal::Ptr journal = IncidenceDateTime::incidence<KCalendarCore::Journal>()) {
+    } else if (KCalendarCore::Journal::Ptr const journal = IncidenceDateTime::incidence<KCalendarCore::Journal>()) {
         load(journal, isTemplate, templateOverridesTimes);
     } else {
         qCDebug(INCIDENCEEDITOR_LOG) << "Not an Incidence.";
@@ -160,11 +167,11 @@ void IncidenceDateTime::load(const KCalendarCore::Incidence::Ptr &incidence)
 
 void IncidenceDateTime::save(const KCalendarCore::Incidence::Ptr &incidence)
 {
-    if (KCalendarCore::Todo::Ptr todo = IncidenceDateTime::incidence<KCalendarCore::Todo>(incidence)) {
+    if (KCalendarCore::Todo::Ptr const todo = IncidenceDateTime::incidence<KCalendarCore::Todo>(incidence)) {
         save(todo);
-    } else if (KCalendarCore::Event::Ptr event = IncidenceDateTime::incidence<KCalendarCore::Event>(incidence)) {
+    } else if (KCalendarCore::Event::Ptr const event = IncidenceDateTime::incidence<KCalendarCore::Event>(incidence)) {
         save(event);
-    } else if (KCalendarCore::Journal::Ptr journal = IncidenceDateTime::incidence<KCalendarCore::Journal>(incidence)) {
+    } else if (KCalendarCore::Journal::Ptr const journal = IncidenceDateTime::incidence<KCalendarCore::Journal>(incidence)) {
         save(journal);
     } else {
         Q_ASSERT_X(false, "IncidenceDateTimeEditor::save", "Only implemented for todos, events and journals");
@@ -173,11 +180,11 @@ void IncidenceDateTime::save(const KCalendarCore::Incidence::Ptr &incidence)
 
 bool IncidenceDateTime::isDirty() const
 {
-    if (KCalendarCore::Todo::Ptr todo = IncidenceDateTime::incidence<KCalendarCore::Todo>()) {
+    if (KCalendarCore::Todo::Ptr const todo = IncidenceDateTime::incidence<KCalendarCore::Todo>()) {
         return isDirty(todo);
-    } else if (KCalendarCore::Event::Ptr event = IncidenceDateTime::incidence<KCalendarCore::Event>()) {
+    } else if (KCalendarCore::Event::Ptr const event = IncidenceDateTime::incidence<KCalendarCore::Event>()) {
         return isDirty(event);
-    } else if (KCalendarCore::Journal::Ptr journal = IncidenceDateTime::incidence<KCalendarCore::Journal>()) {
+    } else if (KCalendarCore::Journal::Ptr const journal = IncidenceDateTime::incidence<KCalendarCore::Journal>()) {
         return isDirty(journal);
     } else {
         Q_ASSERT_X(false, "IncidenceDateTimeEditor::isDirty", "Only implemented for todos and events");
@@ -263,7 +270,7 @@ void IncidenceDateTime::updateStartDate(const QDate &newDate)
     const bool dateChanged = mCurrentStartDateTime.date() != newDate;
 
     QDateTime endDateTime = currentEndDateTime();
-    int daysep = mCurrentStartDateTime.daysTo(endDateTime);
+    int const daysep = mCurrentStartDateTime.daysTo(endDateTime);
     mCurrentStartDateTime.setDate(newDate);
     if (mUi->mEndCheck->isChecked()) {
         // Only update the end time when it is actually enabled, adjust end time so
@@ -559,8 +566,16 @@ void IncidenceDateTime::load(const KCalendarCore::Event::Ptr &event, bool isTemp
             setTimes(event->dtStart(), event->dtEnd());
         }
     } else {
-        QDateTime startDT = event->dtStart();
-        QDateTime endDT = event->dtEnd();
+        QDateTime const startDT = event->dtStart();
+        QDateTime const endDT = event->dtEnd();
+        const QDateTime rightNow = QDateTime::currentDateTime();
+        if (mLoadedIncidence->summary().isEmpty()) {
+            if ((mLoadedIncidence->allDay() && endDT.date() < rightNow.date()) || (!mLoadedIncidence->allDay() && endDT.addSecs(1) < rightNow)) {
+                showMessage(i18nc("@info", "The event you are creating ends in the past."), KMessageWidget::Information);
+            } else if ((mLoadedIncidence->allDay() && startDT.date() < rightNow.date()) || (!mLoadedIncidence->allDay() && startDT.addSecs(1) < rightNow)) {
+                showMessage(i18nc("@info", "The event you are creating starts in the past."), KMessageWidget::Information);
+            }
+        }
         setDateTimes(startDT, endDT);
     }
 
@@ -603,7 +618,7 @@ void IncidenceDateTime::load(const KCalendarCore::Journal::Ptr &journal, bool is
             setTimes(journal->dtStart(), QDateTime());
         }
     } else {
-        QDateTime startDT = journal->dtStart();
+        QDateTime const startDT = journal->dtStart();
         // Journals do not have end dates, so pick an arbitrary suitable date.
         setDateTimes(startDT, startDT);
     }
@@ -665,6 +680,15 @@ void IncidenceDateTime::load(const KCalendarCore::Todo::Ptr &todo, bool isTempla
     } else {
         const QDateTime endDT = todo->hasDueDate() ? todo->dtDue(true /** first */) : rightNow;
         const QDateTime startDT = todo->hasStartDate() ? todo->dtStart(true /** first */) : rightNow;
+        if (mLoadedIncidence->summary().isEmpty()) {
+            if ((mLoadedIncidence->allDay() && endDT.date() < rightNow.date()) || (!mLoadedIncidence->allDay() && endDT.addSecs(1) < rightNow)) {
+                showMessage(i18nc("@info", "The to-do you are creating is due in the past. Once saved, it will be adjusted for today's date"),
+                            KMessageWidget::Warning);
+            } else if ((mLoadedIncidence->allDay() && startDT.date() < rightNow.date()) || (!mLoadedIncidence->allDay() && startDT.addSecs(1) < rightNow)) {
+                showMessage(i18nc("@info", "The to-do you are creating starts in the past. Once saved, it will be adjusted for today's date"),
+                            KMessageWidget::Warning);
+            }
+        }
         setDateTimes(startDT, endDT);
     }
 }
@@ -715,7 +739,7 @@ void IncidenceDateTime::setDateTimes(const QDateTime &start, const QDateTime &en
         mUi->mStartTimeEdit->setTime(start.time());
         mUi->mTimeZoneComboStart->selectTimeZoneFor(start);
     } else {
-        QDateTime dt = QDateTime::currentDateTime();
+        QDateTime const dt = QDateTime::currentDateTime();
         mUi->mStartDateEdit->setDate(dt.date());
         mUi->mStartTimeEdit->setTime(dt.time());
         mUi->mTimeZoneComboStart->selectTimeZoneFor(dt);
@@ -726,7 +750,7 @@ void IncidenceDateTime::setDateTimes(const QDateTime &start, const QDateTime &en
         mUi->mEndTimeEdit->setTime(end.time());
         mUi->mTimeZoneComboEnd->selectTimeZoneFor(end);
     } else {
-        QDateTime dt(QDate::currentDate(), QTime::currentTime().addSecs(60 * 60));
+        QDateTime const dt(QDate::currentDate(), QTime::currentTime().addSecs(60 * 60));
         mUi->mEndDateEdit->setDate(dt.date());
         mUi->mEndTimeEdit->setTime(dt.time());
         mUi->mTimeZoneComboEnd->selectTimeZoneFor(dt);
@@ -745,7 +769,7 @@ void IncidenceDateTime::setDateTimes(const QDateTime &start, const QDateTime &en
 void IncidenceDateTime::updateStartToolTips()
 {
     if (mUi->mStartCheck->isChecked()) {
-        QString datetimeStr = KCalUtils::IncidenceFormatter::dateTimeToString(currentStartDateTime(), mUi->mWholeDayCheck->isChecked(), false);
+        QString const datetimeStr = KCalUtils::IncidenceFormatter::dateTimeToString(currentStartDateTime(), mUi->mWholeDayCheck->isChecked(), false);
         mUi->mStartDateEdit->setToolTip(i18nc("@info:tooltip", "Starts: %1", datetimeStr));
         mUi->mStartTimeEdit->setToolTip(i18nc("@info:tooltip", "Starts: %1", datetimeStr));
     } else {
@@ -757,7 +781,7 @@ void IncidenceDateTime::updateStartToolTips()
 void IncidenceDateTime::updateEndToolTips()
 {
     if (mUi->mStartCheck->isChecked()) {
-        QString datetimeStr = KCalUtils::IncidenceFormatter::dateTimeToString(currentEndDateTime(), mUi->mWholeDayCheck->isChecked(), false);
+        QString const datetimeStr = KCalUtils::IncidenceFormatter::dateTimeToString(currentEndDateTime(), mUi->mWholeDayCheck->isChecked(), false);
         if (mLoadedIncidence->type() == KCalendarCore::Incidence::TypeTodo) {
             mUi->mEndDateEdit->setToolTip(i18nc("@info:tooltip", "Due on: %1", datetimeStr));
             mUi->mEndTimeEdit->setToolTip(i18nc("@info:tooltip", "Due on: %1", datetimeStr));
@@ -914,7 +938,7 @@ void IncidenceDateTime::printDebugInfo() const
 
     qCDebug(INCIDENCEEDITOR_LOG) << "dirty test1: " << (mLoadedIncidence->allDay() != mUi->mWholeDayCheck->isChecked());
     if (mLoadedIncidence->type() == KCalendarCore::Incidence::TypeEvent) {
-        KCalendarCore::Event::Ptr event = mLoadedIncidence.staticCast<KCalendarCore::Event>();
+        KCalendarCore::Event::Ptr const event = mLoadedIncidence.staticCast<KCalendarCore::Event>();
         qCDebug(INCIDENCEEDITOR_LOG) << "dirty test2: " << (mUi->mFreeBusyCheck->isChecked() && event->transparency() != KCalendarCore::Event::Opaque);
         qCDebug(INCIDENCEEDITOR_LOG) << "dirty test3: " << (!mUi->mFreeBusyCheck->isChecked() && event->transparency() != KCalendarCore::Event::Transparent);
     }
